Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.Anrede Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.Anrede einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.Anrede) | Gemeinde_Modelle.Anrede |
__str__(self) (Definiert in Gemeinde_Modelle.Anrede) | Gemeinde_Modelle.Anrede |
keyFeldNavi (Definiert in Gemeinde_Modelle.Anrede) | Gemeinde_Modelle.Anrede | static